# nicescad
nicescad brings OpenScad to the browser (again)

[![Join the discussion at https://github.com/WolfgangFahl/nicescad/discussions](https://img.shields.io/github/discussions/WolfgangFahl/nicescad)](https://github.com/WolfgangFahl/nicescad/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/nicescad)](https://pypi.org/project/nicescad/)
[![Github Actions Build](https://github.com/WolfgangFahl/nicescad/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/nicescad/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/nicescad.svg)](https://pypi.python.org/pypi/nicescad/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/nicescad.svg)](https://github.com/WolfgangFahl/nicescad/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/nicescad.svg)](https://github.com/WolfgangFahl/nicescad/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/nicescad/)
[![License](https://img.shields.io/github/license/WolfgangFahl/nicescad.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Demo
[Demo](http://nicescad.bitplan.com/)

## Docs and Tutorials
[Wiki](https://wiki.bitplan.com/index.php/nicescad)

## Examples
* [Basics/logo](https://raw.githubusercontent.com/openscad/openscad/master/examples/Basics/logo.scad)
* [Intersection](https://raw.githubusercontent.com/WolfgangFahl/nicescad/main/examples/intersection.scad)

## Links
* https://openscad.org/
* https://nicegui.io
### Alternative online editors
* https://ochafik.com/openscad2/
* http://www.implicitcad.org/editor
* https://www.blockscad3d.com/editor/
* https://openjscad.azurewebsites.net/
* https://openjscad.xyz/
### Jupyter notebook integration
* https://github.com/nickc92/ViewSCAD
### Python integration
* https://github.com/jeff-dh/SolidPython
